# -*- coding: utf-8 -*-
from odoo import fields, models, api


class AccountAnalyticAccount(models.Model):
    """Override analytic account to avoid duplicate code fields."""

    _inherit = 'account.analytic.account'

    _sql_constraints = [
        ('code_unique',
         'unique (code)',
         """Analytic Account/Subscription reference must be unique."""),
    ]

    code = fields.Char(copy=False)


class AccountAnalyticLine(models.Model):

    _inherit = "account.analytic.line"

    move_line_id = fields.Many2one(check_company=False)

    @api.model
    def _default_account_id(self):
        if self._context.get('sale_line_id'):
            sale_line_id = self.env['sale.order.line'].browse(self._context['sale_line_id'])
            if sale_line_id.order_id.analytic_account_id:
                return sale_line_id.order_id.analytic_account_id.id
        if self._context.get('sale_order_id'):
            sale_order_id = self.env['sale.order'].browse(self._context['sale_order_id'])
            if sale_order_id.analytic_account_id:
                return sale_order_id.analytic_account_id.id

    account_id = fields.Many2one(default=_default_account_id)
